/*
 * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
 * SUN PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * Copyright 2007 IBM Corporation
 */

package com.sun.ts.tests.portlet.api.javax_portlet.PortletRequestDispatcher;

import com.sun.javatest.Status;
import com.sun.ts.tests.common.webclient.http.HttpResponse;
import com.sun.ts.tests.portlet.common.client.ExtendedPortletUrlClient;
import com.sun.ts.tests.portlet.common.client.TSPortletInfo;
import com.sun.ts.tests.portlet.common.client.tags.PortletURLClientTag;
import com.sun.ts.tests.portlet.common.util.ResultWriter;

/**
 * URLClient and SpecURLClient are used as HTTP test clients to test
 * the Portlet API and specification assertions.  Each assertion test
 * is performed by executing a method in the *URLClient class that has
 * the @testName, @assertion_ids, @test_Strategy, and @assertion tags
 * in its javadoc comments.
 * <p>
 * In each test, at least one HTTP request is made to retrieve the
 * portal page that interacts with portlets that participate in the
 * corresponding test.  These test portlets/servlets, bundled in WAR
 * files, are assumed to be already deployed on the portal server
 * before the test is run.  The initial URL of the portal page is
 * obtained, using either declarative or programmatic configuration,
 * by the base class method <code>getPortalURL</code>, and is set for
 * the test using the <code>setRequestProperty</code> method.  See the
 * Technology Compatibility Kit Requirements chapter of the Portlet
 * Specification for details.  Subsequent requests for the test are
 * done using URLs, generated by PortletURL, that are part of the
 * returned portal pages.
 * <p>
 * The test sets the test success criteria using the
 * <code>setCriteriaProperty</code> method to look for either expected
 * or unexpected substrings in the portal page returned to decide
 * whether a test has passed or failed.
 * <p>
 * Finally, the <code>invoke()</code> method makes the HTTP request
 * and validates the output for the configured success criteria.  In
 * case of failure, this method throws a <code>Fault</code> exception
 * that is caught by the framework to report a failure for the test. 
 * 
 * @author Oliver Spindler <olisp_suhl@yahoo.com> (since JSR 268)
 * 
 */
public class SpecURLClient extends ExtendedPortletUrlClient {
	
	static final long serialVersionUID = 286L;

	public static void main(String[] args) {
		SpecURLClient theTests = new SpecURLClient();
		Status status = theTests.run(args, System.out, System.err);
		status.exit();
	}

	/*
	 * @class.setup_props: ts_home;
	 */                    

	/**
	 * Returns the name of the default portlet app.
	 */
	public String getDefaultPortletApp() {
		return "portlet_jp_PortletRequestDispatcher_web";
	}

	//*******************************************************************************
	//*                             Include Tests                                   *
	//*******************************************************************************

	/*
	 * @testName: AccessToPathActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:183;PORTLET:SPEC:235
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a query string 
     *                 to include the servlet in processAction().  
	 *                 Checks that the specified attributes are correctly set 
	 *                 in the included servlet via getAttribute.
	 * @assertion: Except for servlets obtained by using the
	 *             getNamedDispatcher method, a servlet or JSP being
	 *             used from within an include call has access to the
	 *             path used to obtain the PortletRequestDispatcher.
	 *             The following request attributes must be set:
	 *             javax.servlet.include.request_uri,
	 *             javax.servlet.include.context_path,
	 *             javax.servlet.include.servlet_path,
	 *             javax.servlet.include.path_info,
	 *             javax.servlet.include.query_string.
	 */

	public void AccessToPathActionIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"AccessToPathActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}


	/*
	 * @testName: AccessToPathEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:183;PORTLET:SPEC:235
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher created with a query string
     *                 to include the servlet. 
     *                 Checks that the specified attributes are correctly set 
	 *                 in the included servlet via getAttribute.
	 * @assertion: Except for servlets obtained by using the
	 *             getNamedDispatcher method, a servlet or JSP being
	 *             used from within an include call has access to the
	 *             path used to obtain the PortletRequestDispatcher.
	 *             The following request attributes must be set:
	 *             javax.servlet.include.request_uri,
	 *             javax.servlet.include.context_path,
	 *             javax.servlet.include.servlet_path,
	 *             javax.servlet.include.path_info,
	 *             javax.servlet.include.query_string.
	 */

	public void AccessToPathEventingIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"AccessToPathEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}


	/*
	 * @testName: AccessToPathRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:127;PORTLET:SPEC:128.1;PORTLET:SPEC:183;PORTLET:SPEC:235
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher created with a query string 
	 *                 to include the servlet. Checks that the specified 
	 *                 attributes are correctly set in the included 
	 *                 servlet via getAttribute.
	 * @assertion: Except for servlets obtained by using the
	 *             getNamedDispatcher method, a servlet or JSP being
	 *             used from within an include call has access to the
	 *             path used to obtain the PortletRequestDispatcher.
	 *             The following request attributes must be set:
	 *             javax.servlet.include.request_uri,
	 *             javax.servlet.include.context_path,
	 *             javax.servlet.include.servlet_path,
	 *             javax.servlet.include.path_info,
	 *             javax.servlet.include.query_string.
	 */

	public void AccessToPathRenderIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"AccessToPathRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: AccessToPathServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:183;PORTLET:SPEC:235
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a 
     *                 query string to include the servlet 
     *                 in serveResource(). Checks that 
	 *                 the specified attributes are correctly set in the 
	 *                 included servlet via getAttribute.
	 * @assertion: Except for servlets obtained by using the
	 *             getNamedDispatcher method, a servlet or JSP being
	 *             used from within an include call has access to the
	 *             path used to obtain the PortletRequestDispatcher.
	 *             The following request attributes must be set:
	 *             javax.servlet.include.request_uri,
	 *             javax.servlet.include.context_path,
	 *             javax.servlet.include.servlet_path,
	 *             javax.servlet.include.path_info,
	 *             javax.servlet.include.query_string.
	 */

	public void AccessToPathServeResourceIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"AccessToPathServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo);	
	}	    


	/*
	 * @testName: IncludeNonexistingServletTest
	 * @assertion_ids: PORTLET:SPEC:122;PORTLET:SPEC:178
	 * @test_Strategy: Invokes PortletContext.getNamedDispatcher()
	 *                 with a non-existing servlet and checks that the
	 *                 returned value is null.
	 * @assertion: If no resource can be resolved based on the given
	 *             path or name the methods must return null.
	 */
	public void IncludeNonexistingServletTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"IncludeNonexistingServletTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: IncludedRequestAttributesActionTest
	 * @assertion_ids: PORTLET:SPEC:184
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction().
	 *                 Checks the specified attributes for the correct 
	 *                 types and values in the included servlet.
	 * @assertion: In addition to the request attributes specified in
	 *             Servlet Specification, SRV.8.3.1 Section, the
	 *             included servlet or JSP must have the following
	 *             request attributes set:
	 *             javax.portlet.config javax.portlet.PortletConfig,
	 *             javax.portlet.request javax.portlet.ActionRequest,
	 *             javax.portlet.response javax.portlet.ActionResponse. 
	 *             These attributes must be the same portlet API
	 *             objects accessible to the portlet doing the include 
	 *             call.
	 */

	public void IncludedRequestAttributesActionTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"IncludedRequestAttributesActionTestPortlet");

		runStdTestForProcessAction(portletInfo);       	    
	}


	/*
	 * @testName: IncludedRequestAttributesEventingTest
	 * @assertion_ids: PORTLET:SPEC:184
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 Checks the specified attributes for the correct types and 
     *                 values in the included servlet.
	 * @assertion: In addition to the request attributes specified in
	 *             Servlet Specification, SRV.8.3.1 Section, the
	 *             included servlet or JSP must have the following
	 *             request attributes set:
	 *             javax.portlet.config javax.portlet.PortletConfig,
	 *             javax.portlet.request javax.portlet.EventRequest,
	 *             javax.portlet.response javax.portlet.EventResponse. 
	 *             These attributes must be the same portlet API
	 *             objects accessible to the portlet doing the include 
	 *             call.
	 */

	public void IncludedRequestAttributesEventingTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"IncludedRequestAttributesEventingTestPortlet");

		runStdTestForProcessEvent(portletInfo);	    
	}


	/*
	 * @testName: IncludedRequestAttributesRenderTest
	 * @assertion_ids: PORTLET:SPEC:128;PORTLET:SPEC:184
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. Checks the specified attributes for 
	 *                 the correct types and values in the included servlet.
	 * @assertion: In addition to the request attributes specified in
	 *             Servlet Specification, SRV.8.3.1 Section, the
	 *             included servlet or JSP must have the following
	 *             request attributes set:
	 *             javax.portlet.config javax.portlet.PortletConfig,
	 *             javax.portlet.request javax.portlet.RenderRequest,
	 *             javax.portlet.response javax.portlet.RenderResponse. 
	 *             These attributes must be the same portlet API
	 *             objects accessible to the portlet doing the include 
	 *             call.
	 */

	public void IncludedRequestAttributesRenderTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"IncludedRequestAttributesRenderTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: IncludedRequestAttributesServeResourceTest
	 * @assertion_ids: PORTLET:SPEC:184
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). Checks the specified 
	 *                 attributes for the correct types and 
     *                 values in the included servlet.
	 * @assertion: In addition to the request attributes specified in
	 *             Servlet Specification, SRV.8.3.1 Section, the
	 *             included servlet or JSP must have the following
	 *             request attributes set:
	 *             javax.portlet.config javax.portlet.PortletConfig,
	 *             javax.portlet.request javax.portlet.ResourceRequest,
	 *             javax.portlet.response javax.portlet.ResourceResponse. 
	 *             These attributes must be the same portlet API
	 *             objects accessible to the portlet doing the include 
	 *             call.
	 */

	public void IncludedRequestAttributesServeResourceTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"IncludedRequestAttributesServeResourceTestPortlet");

		runStdTestForServeResource(portletInfo); 	    
	}


	/*
	 * @testName: QueryStringParametersActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:179
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a 
     *                 query string to include the servlet in processAction(). 
     *                 Test passes if the parameters 
	 *                 specified in the query string takes precendence over 
	 *                 other parameters of the same name passed to 
	 *                 the included servlet.
	 * @assertion: Parameters specified in the query string used to
	 *             create the PortletRequestDispatcher must be aggregated
	 *             with the portlet render parameters and take precedence
	 *             over other portlet render parameters of the same
	 *             name passed to the included servlet or JSP.
	 */
	public void QueryStringParametersActionIncludeTest() throws Fault {

		TSPortletInfo portletInfo = 
			new TSPortletInfo(getDefaultPortletApp(),
			"QueryStringParametersActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);  
	}


	/*
	 * @testName: QueryStringParametersEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:179
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher created with a query string
     *                 to include the servlet. Test passes if the parameters 
	 *                 specified in the query string takes precendence over 
	 *                 other parameters of the same name passed to 
	 *                 the included servlet.
	 * @assertion: Parameters specified in the query string used to
	 *             create the PortletRequestDispatcher must be aggregated
	 *             with the portlet render parameters and take precedence
	 *             over other portlet render parameters of the same
	 *             name passed to the included servlet or JSP.
	 */
	public void QueryStringParametersEventingIncludeTest() throws Fault {

		TSPortletInfo portletInfo = 
			new TSPortletInfo(getDefaultPortletApp(),
			"QueryStringParametersEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);	
	}	


	/*
	 * @testName: QueryStringParametersRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:123;PORTLET:SPEC:179
	 * @test_Strategy: In the first request the portlet creates a
	 *                 renderURL with parameters set using createRenderURL(). 
	 *                 In the second request with that URL the portlet uses a 
	 *                 PortletRequestDispatcher created with a query string
	 *                 to include the servlet. Test passes if the parameters 
	 *                 specified in the query string takes precendence over 
	 *                 other parameters of the same name passed to 
	 *                 the included servlet.
	 * @assertion: Parameters specified in the query string used to
	 *             create the PortletRequestDispatcher must be aggregated
	 *             with the portlet render parameters and take precedence
	 *             over other portlet render parameters of the same
	 *             name passed to the included servlet or JSP.
	 */
	public void QueryStringParametersRenderIncludeTest() throws Fault {

		TSPortletInfo portletInfo = 
			new TSPortletInfo(getDefaultPortletApp(),
					"QueryStringParametersRenderIncludeTestPortlet");

		runStdTestForRenderWithParameters(portletInfo);  
	}


	/*
	 * @testName: QueryStringParametersServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:179
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a query string 
     *                 to include the servlet in serveResource(). Test passes if 
	 *                 the parameters specified in the query string takes 
	 *                 precendence over other parameters of the same name 
	 *                 passed to the included servlet.
	 * @assertion: Parameters specified in the query string used to
	 *             create the PortletRequestDispatcher must be aggregated
	 *             with the portlet render parameters and take precedence
	 *             over other portlet render parameters of the same
	 *             name passed to the included servlet or JSP.
	 */
	public void QueryStringParametersServeResourceIncludeTest() throws Fault {

		TSPortletInfo portletInfo = 
			new TSPortletInfo(getDefaultPortletApp(),
					"QueryStringParametersServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo); 	    
	}	    


	/*
	 * @testName: RequestMethodsAttributeMiscActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:188
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets some 
     *                 attributes and uses a PortletRequestDispatcher 
     *                 to include the servlet in processAction(). 
     *                 Checks for these attributes using getAttribute 
     *                 and getAttributeNames in the included servlet.  
     *                 The servlet removes a attribute and sets another 
     *                 attribute.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 include() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscActionIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo); 	

	}


	/*
	 * @testName: RequestMethodsAttributeMiscEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:188
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is 
     *                 invoked it sets some attributes and uses a 
     *                 PortletRequestDispatcher to include the servlet. 
     *                 Checks for the attributes 
	 *                 using getAttribute and getAttributeNames in
	 *                 the included servlet.  Removes a attribute
	 *                 and sets another attribute in the servlet.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 include() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscEventingIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);      
	}


	/*
	 * @testName: RequestMethodsAttributeMiscRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:131;PORTLET:SPEC:207
	 * @test_Strategy: Makes a request to the portlet that 
	 *                 sets attributes and uses a PortletRequestDispatcher 
	 *                 to include the servlet. Checks for the attributes 
	 *                 using getAttribute and getAttributeNames in
	 *                 the included servlet.  Removes a attribute
	 *                 and sets another attribute in the servlet.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 include() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscRenderIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: RequestMethodsAttributeMiscServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:223
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet sets some attributes 
     *                 and uses a PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). Checks for the attributes 
	 *                 using getAttribute and getAttributeNames in
	 *                 the included servlet. Removes a attribute
	 *                 and sets another attribute in the servlet.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 include() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscServeResourceIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo);    	
	}

	/*
	 * @testName: RequestMethodsGetInputStreamActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:190
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction().
	 *                 In the servlet the getInputStream method is invoked. 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the ServletInputStream object.
	 * @assertion: In case of an include from processAction, the following 
	 *             method of the HttpServletRequest must be based on the 
	 *             corresponding methods of the ActionRequest: 
	 *             getInputStream().
	 */
	public void RequestMethodsGetInputStreamActionIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetInputStreamEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:191
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
	 *                 In the servlet the getInputStream method is invoked. 
	 *                 Test passes if this method returns null.
	 * @assertion: In case of an include from processEvent, the following 
	 *             method of the HttpServletRequest return null: 
	 *             getInputStream().
	 */
	public void RequestMethodsGetInputStreamEventingIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetInputStreamRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:209
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. In the servlet the getInputStream
	 *                 method is invoked. Test passes if this 
	 *                 method returns null.
	 * @assertion: The following method of the HttpServletRequest 
	 *             must do no operations and return null: getInputStream().
	 */
	public void RequestMethodsGetInputStreamRenderIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetInputStreamServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:224;
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). 
	 *                 In the servlet the getInputStream
	 *                 method is invoked. Test passes if this method 
	 *                 returns a non-null value  for 
	 *                 the ServletInputStream object.
	 * @assertion: The HttpServletRequest getInputStream must be 
	 *             equivalent to the method getPortletInputStream 
	 *             of the ResourceRequest.
	 */
	public void RequestMethodsGetInputStreamServeResourceIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetReaderActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:190
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction().
	 *                 In the servlet the getReader method is invoked. 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the BufferedReader object.
	 * @assertion: In case of an include from processAction, the following 
	 *             method of the HttpServletRequest must be based on the 
	 *             corresponding methods of the ActionRequest: 
	 *             getReader().
	 */
	public void RequestMethodsGetReaderActionIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetReaderEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:191
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet. 
	 *                 In the servlet the getReader method is invoked. 
	 *                 Test passes if this method returns null.
	 * @assertion: In case of an include from processEvent, the following 
	 *             method of the HttpServletRequest return null:  
	 *             getReader().
	 */
	public void RequestMethodsGetReaderEventingIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetReaderRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:209
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. In the servlet the getReader 
	 *                 method is invoked. Test passes if this 
	 *                 method returns null.
	 * @assertion: The following method of the HttpServletRequest 
	 *             must do no operations and return null: getReader().
	 */
	public void RequestMethodsGetReaderRenderIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: RequestMethodsGetReaderServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:224
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). In the servlet 
	 *                 the getReader method is invoked. Test passes if 
	 *                 this method returns a non-null value for the 
	 *                 BufferedReader object.
	 * @assertion: The following method of the HttpServletRequest must be  
	 *             equivalent to the method of the ResourceRequest of 
	 *             similar name: getReader().
	 */
	public void RequestMethodsGetReaderServeResourceIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
	

	/*
	 * @testName: RequestMethodsGetRequestDispatcherActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:195
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction().
	 *                 In the servlet the getRequestDispatcher(path) 
	 *                 is invoked (path is pointing to a installed jsp). 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherActionIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);

	}


	/*
	 * @testName: RequestMethodsGetRequestDispatcherEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:195
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 In the servlet the getRequestDispatcher(path) is invoked 
     *                 (path is pointing to a installed jsp). Test passes
	 *                 if this method returns a non-null value for the 
	 *                 request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherEventingIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}

	/*
	 * @testName: RequestMethodsGetRequestDispatcherRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:136;PORTLET:SPEC:212
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include the servlet.
	 *                 In the servlet the getRequestDispatcher(path) 
	 *                 is invoked (path is pointing to a installed jsp). 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherRenderIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: RequestMethodsGetRequestDispatcherServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:227
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource().
	 *                 In the servlet the getRequestDispatcher(path) 
	 *                 is invoked (path is pointing to a installed jsp). 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherServeResourceIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo); 	    

	}


	/*
	 * @testName: RequestMethodsLocaleMiscActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:188
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscActionIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo); 
	}

	/*
	 * @testName: RequestMethodsLocaleMiscEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:188
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscEventingIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}

	/*
	 * @testName: RequestMethodsLocaleMiscRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:131;PORTLET:SPEC:207
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the expected 
	 *                 values saved in the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscRenderIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}

	/*
	 * @testName: RequestMethodsLocaleMiscServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:223
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscServeResourceIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo); 	
	}


	/*
	 * @testName: RequestMethodsMiscMiscActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:188
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). 
	 *                 The servlet compares the return values of 
	 *                 the specified methods with the expected 
	 *                 values saved in the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscActionIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo); 
	}


	/*
	 * @testName: RequestMethodsMiscMiscEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:188
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.   
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscEventingIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}


	/*
	 * @testName: RequestMethodsMiscMiscRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:131;PORTLET:SPEC:207
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the expected 
	 *                 values saved in the session.  
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscRenderIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: RequestMethodsMiscMiscServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:223
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.  
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscServeResourceIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo); 
	}


	/*
	 * @testName: RequestMethodsParameterMiscActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:189
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL with parameters using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscActionIncludeTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo); 
	}


	/*
	 * @testName: RequestMethodsParameterMiscEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:189
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL with parameters using createActionURL() . 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session. 
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscEventingIncludeTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}


	/*
	 * @testName: RequestMethodsParameterMiscRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:132;PORTLET:SPEC:208
	 * @test_Strategy: In the first request the portlet creates a
	 *                 render URL with parameters using createRenderURL(). 
	 *                 In the second reques the portlet uses a 
	 *                 PortletRequestDispatcher to include the servlet. 
	 *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscRenderIncludeTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscRenderIncludeTestPortlet");

		runStdTestForRenderWithParameters(portletInfo);
	}


	/*
	 * @testName: RequestMethodsParameterMiscServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:225
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL with parameters using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session. 
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscServeResourceIncludeTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo); 
	}


	/*
	 * @testName: RequestMethodsReturn0ActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:186
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). 
	 *                 Checks that the specified methods return 0 in the 
	 *                 included servlet.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must return 0: getRemotePort and getLocalPort.          
	 */
	public void RequestMethodsReturn0ActionIncludeTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsReturn0ActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);    	       
	}
    
    
    /*
     * @testName: RequestMethodsReturn0EventingIncludeTest
     * @assertion_ids: PORTLET:SPEC:186
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 Checks that the specified methods return 0 in 
     *                 the included servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return 0: getRemotePort and getLocalPort.        
     */
    public void RequestMethodsReturn0EventingIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturn0EventingIncludeTestPortlet");

        runStdTestForProcessEvent(portletInfo);	
    }
    
    
    /*
     * @testName: RequestMethodsReturn0RenderIncludeTest
     * @assertion_ids: PORTLET:SPEC:205
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. Checks that the specified 
	 *                 methods return 0 in the included servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return 0: getRemotePort and getLocalPort.       
     */
    public void RequestMethodsReturn0RenderIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturn0RenderIncludeTestPortlet");

        runStdTestForRender(portletInfo);
    }

    
    /*
	 * @testName: RequestMethodsReturn0ServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:221
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). Checks that 
	 *                 the specified methods return 0 in the included 
	 *                 servlet.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must return 0: getRemotePort and getLocalPort.    
	 */
	public void RequestMethodsReturn0ServeResourceIncludeTest() throws Fault {
	    /*
	     * Sets the GET request to be sent out to the server.
	     */
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                                    "RequestMethodsReturn0ServeResourceIncludeTestPortlet");
	
	    runStdTestForServeResource(portletInfo); 
	}

	
	/*
     * @testName: RequestMethodsReturnNullActionIncludeTest
     * @assertion_ids: PORTLET:SPEC:185
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). Checks that the 
	 *                 specified methods return null in the included servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return null: getRemoteAddr, getRemoteHost, 
     *             getLocalAddr, getLocalName, getRealPath and getRequestURL.         
     */
    public void RequestMethodsReturnNullActionIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnNullActionIncludeTestPortlet");

        runStdTestForProcessAction(portletInfo); 
    }
    
    
    /*
     * @testName: RequestMethodsReturnNullEventingIncludeTest
     * @assertion_ids: PORTLET:SPEC:185
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 Checks that the specified methods return null in 
     *                 the included servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return null: getRemoteAddr, getRemoteHost, 
     *             getLocalAddr, getLocalName, getRealPath and getRequestURL.        
     */
    public void RequestMethodsReturnNullEventingIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnNullEventingIncludeTestPortlet");

        runStdTestForProcessEvent(portletInfo);
    }
    
    
    /*
     * @testName: RequestMethodsReturnNullRenderIncludeTest
     * @assertion_ids: PORTLET:SPEC:129;(PORTLET:SPEC:133;)PORTLET:SPEC:204
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. Checks that the specified methods 
	 *                 return null in the included servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return null: getRemoteAddr, getRemoteHost, 
     *             getLocalAddr, getLocalName, getRealPath and getRequestURL.        
     */
    public void RequestMethodsReturnNullRenderIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnNullRenderIncludeTestPortlet");

        runStdTestForRender(portletInfo);
    }

    
    /*
	 * @testName: RequestMethodsReturnNullServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:220
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). Checks that 
	 *                 the specified methods return null in the included 
	 *                 servlet.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must return null: getRemoteAddr, getRemoteHost, 
	 *             getLocalAddr, getLocalName, getRealPath and getRequestURL.        
	 */
	public void RequestMethodsReturnNullServeResourceIncludeTest() throws Fault {
	    /*
	     * Sets the GET request to be sent out to the server.
	     */
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                                    "RequestMethodsReturnNullServeResourceIncludeTestPortlet");
	
	    runStdTestForServeResource(portletInfo); 
	}

	
	/*
     * @testName: RequestMethodsReturnPathInfoActionIncludeTest
     * @assertion_ids: PORTLET:SPEC:187
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a 
     *                 query string to include the servlet in processAction(). 
     *                 Checks that the specified methods return correct values 
     *                 in the included servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
    public void RequestMethodsReturnPathInfoActionIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnPathInfoActionIncludeTestPortlet");

        runStdTestForProcessAction(portletInfo);        
    }
	
    
	/*
     * @testName: RequestMethodsReturnPathInfoEventingIncludeTest
     * @assertion_ids: PORTLET:SPEC:187
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher created with a query string
     *                 to include the servlet.
     *                 Checks that the specified methods return correct 
     *                 values in the included servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
    public void RequestMethodsReturnPathInfoEventingIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnPathInfoEventingIncludeTestPortlet");

        runStdTestForProcessEvent(portletInfo);
    }
    
    
	/*
     * @testName: RequestMethodsReturnPathInfoRenderIncludeTest
     * @assertion_ids: PORTLET:SPEC:130;PORTLET:SPEC:206
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher created with 
	 *                 a query string to include the servlet. Checks that 
	 *                 the specified methods return correct values in the 
	 *                 included servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
    public void RequestMethodsReturnPathInfoRenderIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnPathInfoRenderIncludeTestPortlet");

        runStdTestForRender(portletInfo);
    }
    
	/*
     * @testName: RequestMethodsReturnPathInfoServeResourceIncludeTest
     * @assertion_ids: PORTLET:SPEC:222
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a query string 
     *                 to include the servlet in serveResource(). 
     *                 Checks that the specified methods 
     *                 return correct values in the included servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
	public void RequestMethodsReturnPathInfoServeResourceIncludeTest() throws Fault {
	    /*
	     * Sets the GET request to be sent out to the server.
	     */
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                                    "RequestMethodsReturnPathInfoServeResourceIncludeTestPortlet");
	
	    runStdTestForServeResource(portletInfo); 
	}
	
	
	/*
     * @testName: RequestMethodsSecondMiscMiscActionIncludeTest
     * @assertion_ids: PORTLET:SPEC:cxc;PORTLET:SPEC:196
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). 
	 *                 The servlet compares the return values of 
	 *                 the specified methods with the expected 
	 *                 values saved in the session.             
     * @assertion: In case of an include from processAction, the following 
     *             methods of the HttpServletRequest must be based on the 
     *             corresponding methods of the ActionRequest: getCharacterEncoding, 
     *             getContentType, getContentLength and getMethod.
     *             The getProtocol method of the HttpServletRequest must 
     *             always return HTTP/1.1.
     */
    public void RequestMethodsSecondMiscMiscActionIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsSecondMiscMiscActionIncludeTestPortlet");
        
        runStdTestForProcessAction(portletInfo);  	
    }
    
    
    /*
     * @testName: RequestMethodsSecondMiscMiscEventingIncludeTest
     * @assertion_ids: PORTLET:SPEC:191;PORTLET:SPEC:192;PORTLET:SPEC:193;PORTLET:SPEC:196
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.          
     * @assertion: In case of an include from processEvent, the following methods
     *             of the HttpServletRequest must do return null:
     *             getCharacterEncoding, getContentType. The getContentLength 
     *             method of the HttpServletRequest must return 0.
     *             The getProtocol method of the HttpServletRequest must always 
     *             return HTTP/1.1.
     */
    public void RequestMethodsSecondMiscMiscEventingIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsSecondMiscMiscEventingIncludeTestPortlet");
        
        runStdTestForProcessEvent(portletInfo); 
    }
	
    
    /*
     * @testName: RequestMethodsSecondMiscMiscRenderIncludeTest
     * @assertion_ids: PORTLET:SPEC:133;PORTLET:SPEC:134;PORTLET:SPEC:137;
     *                 PORTLET:SPEC:209;PORTLET:SPEC:210;PORTLET:SPEC:213;PORTLET:SPEC:214
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the expected 
	 *                 values saved in the session.
     * @assertion: The following methods of the HttpServletRequest
     *             return null: getCharacterEncoding and getContentType.
     *             The getContentLength method of the HttpServletRequest 
     *             must return 0.
     *             The getMethod method of the HttpServletRequest must 
     *             always return GET. The getProtocol method of the 
     *             HttpServletRequest must always return HTTP/1.1.             
     */
    public void RequestMethodsSecondMiscMiscRenderIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsSecondMiscMiscRenderIncludeTestPortlet");

        runStdTestForRender(portletInfo);
    }
    
    
    /*
     * @testName: RequestMethodsSecondMiscMiscServeResourceIncludeTest
     * @assertion_ids: PORTLET:SPEC:224;PORTLET:SPEC:228
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session. 
     * @assertion: The following methods of the HttpServletRequest must be 
     *             equivalent to the methods of the ResourceRequest of 
     *             similar name: 
     *             getCharacterEncoding, getContentLength, getContentType 
     *             and getMethod.
     *             The getProtocol method of the HttpServletRequest must 
     *             always return HTTP/1.1.
     */
    public void RequestMethodsSecondMiscMiscServeResourceIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsSecondMiscMiscServeResourceIncludeTestPortlet");
     
        runStdTestForServeResource(portletInfo); 
    }
    
    
    /*
     * @testName: RequestMethodsSessionMiscActionIncludeTest
     * @assertion_ids: PORTLET:SPEC:195
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets a session 
     *                 attribute in thePortletSession with APPLICATION_SCOPE 
     *                 and uses a PortletRequestDispatcher to include
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when include returns.                
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscActionIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscActionIncludeTestPortlet");
        
        runStdTestForProcessAction(portletInfo);  
    }
    
    
    /*
     * @testName: RequestMethodsSessionMiscEventingIncludeTest
     * @assertion_ids: PORTLET:SPEC:195
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 sets a session attribute in the
     *                 PortletSession with APPLICATION_SCOPE and uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when include returns.                
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscEventingIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscEventingIncludeTestPortlet");

        runStdTestForProcessEvent(portletInfo);           
    }

    
    /*
     * @testName: RequestMethodsSessionMiscRenderIncludeTest
     * @assertion_ids: PORTLET:SPEC:212
     * @test_Strategy: Makes a request to the portlet that sets a session 
     *                 attribute in the PortletSession with APPLICATION_SCOPE 
     *                 and uses a PortletRequestDispatcher to include
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when include returns.                
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscRenderIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscRenderIncludeTestPortlet");

        runStdTestForRender(portletInfo);
    }
    
    
    /*
     * @testName: RequestMethodsSessionMiscServeResourceIncludeTest
     * @assertion_ids: PORTLET:SPEC:227
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet sets a session attribute 
     *                 in the PortletSession with APPLICATION_SCOPE 
     *                 and uses a PortletRequestDispatcher to include
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when include returns.                
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscServeResourceIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscServeResourceIncludeTestPortlet");
        
        runStdTestForServeResource(portletInfo); 
    }

    
    /*
	 * @testName: ResponseMethodsGetOutputStreamActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:199
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction().
	 *                 In the servlet the getOutputStream method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             an that ignores any output written to it: getOutputStream.
	 */
	public void ResponseMethodsGetOutputStreamActionIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetOutputStreamEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:199
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
	 *                 In the servlet the getOutputStream method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             an that ignores any output written to it: getOutputStream.
	 */
	public void ResponseMethodsGetOutputStreamEventingIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetOutputStreamRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:139;PORTLET:SPEC:216
	 * @test_Strategy: Makes a Response to the portlet that uses
	 *                 a PortletResponseDispatcher to include
	 *                 the servlet. In the servlet the getOutputStream 
	 *                 method is invoked. Test passes if this 
	 *                 method returns a non-null value for the 
	 *                 PrintOutputStream object.
	 * @assertion: The following methods of the HttpServletResponse 
	 *             must be equivalent to the methods of the RenderResponse 
	 *             of similar name: getOutputStream().
	 */
	public void ResponseMethodsGetOutputStreamRenderIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: ResponseMethodsGetOutputStreamServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:230
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). In the servlet 
	 *                 the getOutputStream method is invoked. Test passes 
	 *                 if this method returns a non-null value for the 
	 *                 PrintOutputStream object.
	 * @assertion: The following method of the HttpServletResponse must be  
	 *             equivalent to the method of the ResourceResponse of 
	 *             similar name: getOutputStream().
	 */
	public void ResponseMethodsGetOutputStreamServeResourceIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
    
    
    /*
	 * @testName: ResponseMethodsGetWriterActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:199
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction().
	 *                 In the servlet the getWriter method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             a writer that ignores any output written to it: getWriter.
	 */
	public void ResponseMethodsGetWriterActionIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetWriterEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:199
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet. 
	 *                 In the servlet the getWriter method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             a writer that ignores any output written to it: getWriter.
	 */
	public void ResponseMethodsGetWriterEventingIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetWriterRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:139;PORTLET:SPEC:216
	 * @test_Strategy: Makes a Response to the portlet that uses
	 *                 a PortletResponseDispatcher to include
	 *                 the servlet. In the servlet the getWriter 
	 *                 method is invoked. Test passes if this 
	 *                 method returns a non-null value for the 
	 *                 PrintWriter object.
	 * @assertion: The following methods of the HttpServletResponse 
	 *             must be equivalent to the methods of the RenderResponse 
	 *             of similar name: getWriter().
	 */
	public void ResponseMethodsGetWriterRenderIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: ResponseMethodsGetWriterServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:230
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). In the servlet the 
	 *                 getWriter method is invoked. Test passes if this 
	 *                 method returns a non-null value for the PrintWriter object.
	 * @assertion: The following method of the HttpServletResponse must be  
	 *             equivalent to the method of the ResourceResponse of 
	 *             similar name: getWriter().
	 */
	public void ResponseMethodsGetWriterServeResourceIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo);
	}

    
	/*
	 * @testName: ResponseMethodsMiscMiscActionIncludeTest
	 * @assertion_ids: PORTLET:SPEC:197;PORTLET:SPEC:198;PORTLET:SPEC:200;PORTLET:SPEC:202
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). 
	 *                 The servlet compares the return values of 
	 *                 the specified methods with the expected 
	 *                 values saved in the session. 
	 * @assertion: The following methods of the HttpServletResponse must 
	 *             return null: getCharacterEncoding, getContentType 
	 *             and getLocale. The following method of the HttpServletResponse 
	 *             must return 0: getBufferSize.
	 *             The isCommitted method of the HttpServletResponse must return true.
	 *             The following methods of the HttpServletResponse must 
	 *             be equivalent to the methods of the ActionResponse
	 *             of similar name: encodeURL and encodeUrl.
	 */
	public void ResponseMethodsMiscMiscActionIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscActionIncludeTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsMiscMiscEventingIncludeTest
	 * @assertion_ids: PORTLET:SPEC:197;PORTLET:SPEC:198;PORTLET:SPEC:200;PORTLET:SPEC:203
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.
	 * @assertion: The following methods of the HttpServletResponse must 
	 *             return null: getCharacterEncoding, getContentType
	 *             and getLocale. The following method of the HttpServletResponse 
	 *             must return 0: getBufferSize.
	 *             The isCommitted method of the HttpServletResponse must return true.
	 *             The following methods of the HttpServletResponse must 
	 *             be equivalent to the methods of the EventResponse 
	 *             of similar name: encodeURL and encodeUrl.
	 */
	public void ResponseMethodsMiscMiscEventingIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscEventingIncludeTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsMiscMiscRenderIncludeTest
	 * @assertion_ids: PORTLET:SPEC:139;PORTLET:SPEC:141;PORTLET:SPEC:216;PORTLET:SPEC:219
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the expected 
	 *                 values saved in the session.
	 * @assertion: The following methods of the HttpServletResponse must be 
	 *             equivalent to the methods of the RenderResponse of
	 *             similar name: getCharacterEncoding, getBufferSize, 
	 *             isCommitted, encodeURL and encodeUrl.
	 *             The getLocale method of the HttpServletResponse must be 
	 *             based on the getLocale method of the RenderResponse.
	 */
	public void ResponseMethodsMiscMiscRenderIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscRenderIncludeTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: ResponseMethodsMiscMiscServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:230
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session. 
	 * @assertion: The following methods of the HttpServletResponse must be 
	 *             equivalent to the methods of the ResourceResponse of
	 *             similar name: getCharacterEncoding, getContentType, getBufferSize, 
	 *             isCommitted, getLocale, encodeURL and encodeUrl.
	 */
	public void ResponseMethodsMiscMiscServeResourceIncludeTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscServeResourceIncludeTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
	

	/*
     * @testName: ResponseMethodsReturnNullActionIncludeTest
     * @assertion_ids: PORTLET:SPEC:197
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). Checks that the 
	 *                 specified methods return null in the included servlet.
     * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl         
     */
    public void ResponseMethodsReturnNullActionIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "ResponseMethodsReturnNullActionIncludeTestPortlet");

        runStdTestForProcessAction(portletInfo); 
    }
    
    
    /*
     * @testName: ResponseMethodsReturnNullEventingIncludeTest
     * @assertion_ids: PORTLET:SPEC:197
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.  
     *                 Checks that the specified methods return null in 
     *                 the included servlet.
     * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl       
     */
    public void ResponseMethodsReturnNullEventingIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"ResponseMethodsReturnNullEventingIncludeTestPortlet");

        runStdTestForProcessEvent(portletInfo);
    }
    
    
    /*
     * @testName: ResponseMethodsReturnNullRenderIncludeTest
     * @assertion_ids: PORTLET:SPEC:138;PORTLET:SPEC:215
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to include
	 *                 the servlet. Checks that the specified methods 
	 *                 return null in the included servlet.
     * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl.       
     */
    public void ResponseMethodsReturnNullRenderIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"ResponseMethodsReturnNullRenderIncludeTestPortlet");

        runStdTestForRender(portletInfo);
    }

    
    /*
	 * @testName: ResponseMethodsReturnNullServeResourceIncludeTest
	 * @assertion_ids: PORTLET:SPEC:229
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource(). Checks that 
	 *                 the specified methods return null in the included 
	 *                 servlet.
	 * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl.       
	 */
	public void ResponseMethodsReturnNullServeResourceIncludeTest() throws Fault {
	    /*
	     * Sets the GET request to be sent out to the server.
	     */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsReturnNullServeResourceIncludeTestPortlet");
	
	    runStdTestForServeResource(portletInfo); 
	}

    
    /*
     * @testName: SameThreadActionIncludeTest
     * @assertion_ids: PORTLET:SPEC:181
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request processAction() sets a value 
     *                 to a ThreadLocal object in the portlet and uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet. Checks for the value from the
     *                 ThreadLocal object in the included servlet.
     * @assertion: The portlet container must ensure that the servlet
     *             or JSP called through a PortletRequestDispatcher is
     *             called in the same thread as the
     *             PortletRequestDispatcher include invocation.
     */
    public void SameThreadActionIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"SameThreadActionIncludeTestPortlet");
        
        runStdTestForProcessAction(portletInfo); 
    }
    
    
    /*
     * @testName: SameThreadEventingIncludeTest
     * @assertion_ids: PORTLET:SPEC:181
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 sets a value to a ThreadLocal object and uses a 
     *                 PortletRequestDispatcher to include the servlet. 
     *                 Checks for the value from the
     *                 ThreadLocal object in the included servlet.
     * @assertion: The portlet container must ensure that the servlet
     *             or JSP called through a PortletRequestDispatcher is
     *             called in the same thread as the
     *             PortletRequestDispatcher include invocation.
     */
    public void SameThreadEventingIncludeTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"SameThreadEventingIncludeTestPortlet");
        
        runStdTestForProcessEvent(portletInfo);  
    }
    
    
    /*
     * @testName: SameThreadRenderIncludeTest
     * @assertion_ids: PORTLET:SPEC:181
     * @test_Strategy: Makes a request to the portlet that sets a value to
     *                 a ThreadLocal object in the portlet and uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet. Checks for the value from the
     *                 ThreadLocal object in the included servlet.
     * @assertion: The portlet container must ensure that the servlet
     *             or JSP called through a PortletRequestDispatcher is
     *             called in the same thread as the
     *             PortletRequestDispatcher include invocation.
     */
    public void SameThreadRenderIncludeTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"SameThreadRenderIncludeTestPortlet");

    	runStdTestForRender(portletInfo);
    }


    /*
     * @testName: SameThreadServeResourceIncludeTest
     * @assertion_ids: PORTLET:SPEC:181
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet 
     *                 sets a value to a  ThreadLocal object in the 
     *                 portlet and uses a  PortletRequestDispatcher to include
     *                 the servlet. Checks for the value from the
     *                 ThreadLocal object in the included servlet.
     * @assertion: The portlet container must ensure that the servlet
     *             or JSP called through a PortletRequestDispatcher is
     *             called in the same thread as the
     *             PortletRequestDispatcher include invocation.
     */
    public void SameThreadServeResourceIncludeTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"SameThreadServeResourceIncludeTestPortlet");

    	runStdTestForServeResource(portletInfo);     
    }


    //*******************************************************************************
    //*                             Forward Tests                                   *
    //*******************************************************************************


    /*
     * @testName: AccessToPathActionForwardTest
     * @assertion_ids: PORTLET:SPEC:239;PORTLET:SPEC:235
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a 
     *                 query string to forward to the servlet 
     *                 in processAction().  
	 *                 Checks that the specified attributes are correctly set 
	 *                 in the servlet via getAttribute.
     * @assertion: Except for servlets obtained by using the
     *             getNamedDispatcher method, a servlet or JSP being
     *             used from within an forward call has access to the
     *             path used to obtain the PortletRequestDispatcher.
     *             The following request attributes must be set:
     *             javax.servlet.forward.request_uri,
     *             javax.servlet.forward.context_path,
     *             javax.servlet.forward.servlet_path,
     *             javax.servlet.forward.path_info,
     *             javax.servlet.forward.query_string.
     */    
    public void AccessToPathActionForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"AccessToPathActionForwardTestPortlet");

    	runStdTestForProcessAction(portletInfo);
    }


    /*
     * @testName: AccessToPathEventingForwardTest
     * @assertion_ids: PORTLET:SPEC:239;PORTLET:SPEC:235
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher created with 
     *                 a query string to forward to the servlet. 
     *                 Checks that the specified attributes are correctly set 
	 *                 in the servlet via getAttribute.
     * @assertion: Except for servlets obtained by using the
     *             getNamedDispatcher method, a servlet or JSP being
     *             used from within an forward call has access to the
     *             path used to obtain the PortletRequestDispatcher.
     *             The following request attributes must be set:
     *             javax.servlet.forward.request_uri,
     *             javax.servlet.forward.context_path,
     *             javax.servlet.forward.servlet_path,
     *             javax.servlet.forward.path_info,
     *             javax.servlet.forward.query_string.
     */
    public void AccessToPathEventingForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"AccessToPathEventingForwardTestPortlet");

    	runStdTestForProcessEvent(portletInfo);
    }


    /*
     * @testName: AccessToPathRenderForwardTest
     * @assertion_ids: PORTLET:SPEC:239;PORTLET:SPEC:235
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher created with 
	 *                 a query string to forward to
	 *                 the servlet. Checks that the specified 
	 *                 attributes are correctly set 
	 *                 in the servlet via getAttribute.
     * @assertion: Except for servlets obtained by using the
     *             getNamedDispatcher method, a servlet or JSP being
     *             used from within an forward call has access to the
     *             path used to obtain the PortletRequestDispatcher.
     *             The following request attributes must be set:
     *             javax.servlet.forward.request_uri,
     *             javax.servlet.forward.context_path,
     *             javax.servlet.forward.servlet_path,
     *             javax.servlet.forward.path_info,
     *             javax.servlet.forward.query_string.
     */
    public void AccessToPathRenderForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    	"AccessToPathRenderForwardTestPortlet");

    	runStdTestForRender(portletInfo);
    }


    /*
     * @testName: AccessToPathServeResourceForwardTest
     * @assertion_ids: PORTLET:SPEC:239;PORTLET:SPEC:235
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a 
     *                 query string to forward to the servlet 
     *                 in serveResource(). Checks that 
	 *                 the specified attributes are correctly set in the 
	 *                 servlet via getAttribute.
     * @assertion: Except for servlets obtained by using the
     *             getNamedDispatcher method, a servlet or JSP being
     *             used from within an forward call has access to the
     *             path used to obtain the PortletRequestDispatcher.
     *             The following request attributes must be set:
     *             javax.servlet.forward.request_uri,
     *             javax.servlet.forward.context_path,
     *             javax.servlet.forward.servlet_path,
     *             javax.servlet.forward.path_info,
     *             javax.servlet.forward.query_string.
     */
    public void AccessToPathServeResourceForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    	"AccessToPathServeResourceForwardTestPortlet");

    	runStdTestForServeResource(portletInfo);	
    }	  

    
    /*
	 * @testName: MultipleForwardsActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:241
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with 
     *                 a query string to forward to
	 *                 the servlet in processAction().
	 *                 The servlet forwards to another servlet 
	 *                 that checks that the specified attributes 
	 *                 are correctly set via getAttribute
	 *                 
	 * @assertion: Note that these attributes must always reflect the 
	 *             information in the target of the first forward servlet 
	 *             in the situation that multiple forwards and subsequent
	 *             includes are called. 
	 *             The following request attributes must be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */
	public void MultipleForwardsActionForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"MultipleForwardsActionForwardTestPortlet");
	
		runStdTestForProcessAction(portletInfo);
	}

	/*
	 * @testName: MultipleForwardsEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:241
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() 
     *                 is invoked it uses a PortletRequestDispatcher 
     *                 created with a query string to forward to the servlet.
     *                 The servlet forwards to another servlet 
	 *                 that checks that the specified attributes 
	 *                 are correctly set via getAttribute
	 * @assertion: Note that these attributes must always reflect the 
	 *             information in the target of the first forward servlet 
	 *             in the situation that multiple forwards and subsequent
	 *             includes are called. 
	 *             The following request attributes must be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */	
	public void MultipleForwardsEventingForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"MultipleForwardsEventingForwardTestPortlet");
	
		runStdTestForProcessEvent(portletInfo);
	}

	/*
	 * @testName: MultipleForwardsRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:241
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher created with 
	 *                 a query string to forward to the servlet.
	 *                 The servlet forwards to another servlet 
	 *                 that checks that the specified attributes 
	 *                 are correctly set via getAttribute
	 * @assertion: Note that these attributes must always reflect the 
	 *             information in the target of the first forward servlet 
	 *             in the situation that multiple forwards and subsequent
	 *             includes are called. 
	 *             The following request attributes must be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */
	public void MultipleForwardsRenderForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
		"MultipleForwardsRenderForwardTestPortlet");
	
		runStdTestForRender(portletInfo);
	}

	/*
	 * @testName: MultipleForwardsServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:241
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with 
     *                 a query string to forward to the servlet
	 *                 in serveResource(). The servlet forwards 
	 *                 to another servlet that checks that the 
	 *                 specified attributes are correctly set
	 *                 via getAttribute
	 * @assertion: Note that these attributes must always reflect the 
	 *             information in the target of the first forward servlet 
	 *             in the situation that multiple forwards and subsequent
	 *             includes are called. 
	 *             The following request attributes must be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */	
	public void MultipleForwardsServeResourceForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
		"MultipleForwardsServeResourceForwardTestPortlet");
	
		runStdTestForServeResource(portletInfo);	
	}

	
	/*
	 * @testName: PathNotSetActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:242
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher by using 
     *                 the getNamedDispatcher method to forward to
	 *                 the servlet in processAction().  
	 *                 Checks that the specified attributes are null
	 *                 in the servlet via getAttribute.
	 * @assertion: If the forwarded servlet was obtained by using 
	 *             the getNamedDispatcher method, these attributes must 
	 *             not be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */
	
	public void PathNotSetActionForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"PathNotSetActionForwardTestPortlet");
	
		runStdTestForProcessAction(portletInfo);
	}

	/*
	 * @testName: PathNotSetEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:242
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent()
     *                 is invoked it uses a PortletRequestDispatcher
     *                 by using the getNamedDispatcher method to forward to the servlet. 
     *                 Checks that the specified attributes are null 
	 *                 in the servlet via getAttribute.
	 * @assertion: If the forwarded servlet was obtained by using 
	 *             the getNamedDispatcher method, these attributes must 
	 *             not be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */	
	public void PathNotSetEventingForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"PathNotSetEventingForwardTestPortlet");
	
		runStdTestForProcessEvent(portletInfo);
	}

	/*
	 * @testName: PathNotSetRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:242
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher by using the 
	 *                 getNamedDispatcher to forward to
	 *                 the servlet. Checks that the specified 
	 *                 attributes are null in the servlet via getAttribute.
	 * @assertion: If the forwarded servlet was obtained by using 
	 *             the getNamedDispatcher method, these attributes must 
	 *             not be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */	
	public void PathNotSetRenderForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
		"PathNotSetRenderForwardTestPortlet");
	
		runStdTestForRender(portletInfo);
	}

	/*
	 * @testName: PathNotSetServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:242
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher by using the 
     *                 getNamedDispatcherto forward to
	 *                 the servlet in serveResource(). Checks that 
	 *                 the specified attributes are null in the 
	 *                 servlet via getAttribute.
	 * @assertion: If the forwarded servlet was obtained by using 
	 *             the getNamedDispatcher method, these attributes must 
	 *             not be set:
	 *             javax.servlet.forward.request_uri,
	 *             javax.servlet.forward.context_path,
	 *             javax.servlet.forward.servlet_path,
	 *             javax.servlet.forward.path_info,
	 *             javax.servlet.forward.query_string.
	 */	
	public void PathNotSetServeResourceForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
		"PathNotSetServeResourceForwardTestPortlet");
	
		runStdTestForServeResource(portletInfo);	
	}

	
	/*
	 * @testName: RequestMethodsAttributeMiscActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:246
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets some 
     *                 attributes and uses a PortletRequestDispatcher 
     *                 to forward to the servlet in processAction(). 
     *                 Checks for these attributes using getAttribute 
     *                 and getAttributeNames in the servlet.  
     *                 The servlet removes a attribute and sets another 
     *                 attribute.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 forward() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscActionForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo); 	

	}


	/*
	 * @testName: RequestMethodsAttributeMiscEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:246
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is 
     *                 invoked it sets some attributes and uses a 
     *                 PortletRequestDispatcher to forward to the servlet. 
     *                 Checks for these attributes using getAttribute 
     *                 and getAttributeNames in the servlet.  
     *                 The servlet removes a attribute and sets another 
     *                 attribute.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 forward() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscEventingForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);      
	}


	/*
	 * @testName: RequestMethodsAttributeMiscRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:265
	 * @test_Strategy: Makes a request to the portlet that 
	 *                 sets attributes and uses a PortletRequestDispatcher 
	 *                 to forward to the servlet. 
     *                 Checks for these attributes using getAttribute 
     *                 and getAttributeNames in the servlet.  
     *                 The servlet removes a attribute and sets another 
     *                 attribute.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 forward() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscRenderForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscRenderForwardTestPortlet");

		/*****************************************************************
         * FIRST TRIP: To to send the first request to the render() method
         *             that forwards to the servlet.
         *****************************************************************/
        
        String request = getPortalURL(portletInfo);
        setRequestProperty(REQUEST, request);

        /*
         * Sets the test criteria.
         */
        setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
            ResultWriter.getFailedString(getTestName()));

        /*
         * Invokes the test.
         */
        HttpResponse firstResponse = invoke();
                
        
        /*****************************************************************
         * SECOND TRIP: To send the second request to the render() method
         *              to print the result. 
         *****************************************************************/
                  
         /*
          * Sets the second request to be sent out to the server.
          */
        setRequestProperty(REQUEST, request);

        /*
         * Sets the test criteria.
         */
        setCriteriaProperty(SEARCH_STRING,
    	        ResultWriter.getPassedString(getTestName()));

        /*
         * Invokes the test.
         */
        invoke(firstResponse); 	
	}


	/*
	 * @testName: RequestMethodsAttributeMiscServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:281
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet sets some 
     *                 attributes and uses a PortletRequestDispatcher 
     *                 to forward to the servlet. Checks for the attributes 
	 *                 using getAttribute and getAttributeNames in
	 *                 the servlet. Removes a attribute
	 *                 and sets another attribute in the servlet.
	 *                 Checks that the attribute is removed
	 *                 and the new one is set in the portlet when
	 *                 forward() returns.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getAttribute,
	 *             getAttributeNames, setAttribute, removeAttribute.
	 */
	public void RequestMethodsAttributeMiscServeResourceForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsAttributeMiscServeResourceForwardTestPortlet");

		 /*****************************************************************
	     * FIRST TRIP: To get the ResourceURL string.
	     *****************************************************************/
	    
	    String request = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, request);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
	        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    HttpResponse firstResponse = invoke();
	            
	    /*
	     * Extracts the ResourceURL for the serveResource() method from the
	     * content of the HttpResponse of the first pass.
	     */
	    String resourceUrl = PortletURLClientTag.extractContent(firstResponse);
	    
	    /*****************************************************************
	     * SECOND TRIP: To send the second request to the 
	     *              serveResource() method.
	     *****************************************************************/
	              
	     /*
	      * Sets the second request to be sent out to the server.
	      */
	    String secondRequest = getPortalReturnURL(resourceUrl);
	    setRequestProperty(REQUEST, secondRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
		        ResultWriter.getPassedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    HttpResponse secondResponse = invoke(firstResponse);
	    
	    /*****************************************************************
	     * THIRD TRIP: To send the third request to the 
	     *              render() method that prints the result.
	     *****************************************************************/
	              
	     /*
	      * Sets the second request to be sent out to the server.
	      */
	    String thirdRequest = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, thirdRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(SEARCH_STRING,
		        ResultWriter.getPassedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    invoke(secondResponse);
	}
    
	/*
	 * @testName: RequestMethodsGetInputStreamActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:248
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction().
	 *                 In the servlet the getInputStream method is invoked. 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the ServletInputStream object.
	 * @assertion: In case of an include from processAction, the following 
	 *             method of the HttpServletRequest must be based on the 
	 *             corresponding methods of the ActionRequest: 
	 *             getInputStream().
	 */
	public void RequestMethodsGetInputStreamActionForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetInputStreamEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:249
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet.  
	 *                 In the servlet the getInputStream method is invoked. 
	 *                 Test passes if this method returns null.
	 * @assertion: In case of an include from processEvent, the following 
	 *             method of the HttpServletRequest return null: 
	 *             getInputStream().
	 */
	public void RequestMethodsGetInputStreamEventingForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetInputStreamRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:267
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. In the servlet the getInputStream
	 *                 method is invoked. Test passes if this 
	 *                 method returns null.
	 * @assertion: The following method of the HttpServletRequest 
	 *             must do no operations and return null: getInputStream().
	 */
	public void RequestMethodsGetInputStreamRenderForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetInputStreamServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:282;
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). In the servlet 
	 *                 the getInputStream method is invoked. 
	 *                 Test passes if this method returns a non-null value
	 *                 for the ServletInputStream object.
	 * @assertion: The HttpServletRequest getInputStream must be 
	 *             equivalent to the method getPortletInputStream 
	 *             of the ResourceRequest.
	 */
	public void RequestMethodsGetInputStreamServeResourceForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetInputStreamServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetReaderActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:248
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction().
	 *                 In the servlet the getReader method is invoked. 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the BufferedReader object.
	 * @assertion: In case of an include from processAction, the following 
	 *             method of the HttpServletRequest must be based on the 
	 *             corresponding methods of the ActionRequest: 
	 *             getReader().
	 */
	public void RequestMethodsGetReaderActionForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetReaderEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:249
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet.  
	 *                 In the servlet the getReader method is invoked. 
	 *                 Test passes if this method returns null.
	 * @assertion: In case of an include from processEvent, the following 
	 *             method of the HttpServletRequest return null:  
	 *             getReader().
	 */
	public void RequestMethodsGetReaderEventingForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetReaderRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:267
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. In the servlet the getReader 
	 *                 method is invoked. Test passes if this 
	 *                 method returns null.
	 * @assertion: The following method of the HttpServletRequest 
	 *             must do no operations and return null: getReader().
	 */
	public void RequestMethodsGetReaderRenderForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: RequestMethodsGetReaderServeResourceForwardTest
	 * @assertion_ids: #rev31#kap19#282
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). In the servlet 
	 *                 the getReader method is invoked. Test passes if 
	 *                 this method returns a non-null value for 
	 *                 the BufferedReader object.
	 * @assertion: The following method of the HttpServletRequest must be  
	 *             equivalent to the method of the ResourceRequest of 
	 *             similar name: getReader().
	 */
	public void RequestMethodsGetReaderServeResourceForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetReaderServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
	
	/*
	 * @testName: RequestMethodsGetRequestDispatcherActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:253
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction().
	 *                 In the servlet the getRequestDispatcher(path) method 
	 *                 is invoked (path is pointing to a installed jsp). 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherActionForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo);

	}


	/*
	 * @testName: RequestMethodsGetRequestDispatcherEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:253
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet.  
     *                 In the servlet the getRequestDispatcher(path) method is invoked 
     *                 (path is pointing to a installed jsp). Test passes
	 *                 if this method returns a non-null value for the 
	 *                 request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherEventingForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}

	/*
	 * @testName: RequestMethodsGetRequestDispatcherRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:270
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to the servlet.
	 *                 In the servlet the getRequestDispatcher(path) method 
	 *                 is invoked (path is pointing to a installed jsp). 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherRenderForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: RequestMethodsGetRequestDispatcherServeResourceForwardTest
	 * @assertion_ids: #rev31#kap19#285
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource().
	 *                 In the servlet the getRequestDispatcher(path) method 
	 *                 is invoked (path is pointing to a installed jsp). 
	 *                 Test passes if this method returns a non-null value 
	 *                 for the request dispatcher object.
	 * @assertion: The getRequestDispatcher() method of the
	 *             HttpServletRequest must provide the functionality
	 *             defined by the Servlet Specification.
	 */
	public void RequestMethodsGetRequestDispatcherServeResourceForwardTest() 
		throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsGetRequestDispatcherServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo); 	    

	}


	/*
	 * @testName: RequestMethodsLocaleMiscActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:246
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscActionForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo); 
	}

	/*
	 * @testName: RequestMethodsLocaleMiscEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:246
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscEventingForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}

	/*
	 * @testName: RequestMethodsLocaleMiscRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:265
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the 
	 *                 expected values saved in the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscRenderForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}

	/*
	 * @testName: RequestMethodsLocaleMiscServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:281
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.    
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getLocale, getLocales.
	 */
	public void RequestMethodsLocaleMiscServeResourceForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsLocaleMiscServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo); 	
	}


	/*
	 * @testName: RequestMethodsMiscMiscActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:246
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.   
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscActionForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo); 
	}


	/*
	 * @testName: RequestMethodsMiscMiscEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:246
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.   
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscEventingForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}


	/*
	 * @testName: RequestMethodsMiscMiscRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:265
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the 
	 *                 expected values saved in the session. 
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscRenderForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}


	/*
	 * @testName: RequestMethodsMiscMiscServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:281
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session. 
	 * @assertion: The following methods of the HttpServletRequest
	 *             must be equivalent to the methods of the
	 *             PortletRequest of similar name: getScheme,
	 *             getServerName, getServerPort, isSecure,
	 *             getAuthType, getContextPath, getRemoteUser,
	 *             getUserPrincipal, getRequestedSessionId,
	 *             isRequestedSessionIdValid and getCookies.
	 */
	public void RequestMethodsMiscMiscServeResourceForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsMiscMiscServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo); 
	}


	/*
	 * @testName: RequestMethodsParameterMiscActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:247
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL with parameters using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscActionForwardTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo); 
	}


	/*
	 * @testName: RequestMethodsParameterMiscEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:247
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL with parameters using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.  
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscEventingForwardTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}


	/*
	 * @testName: RequestMethodsParameterMiscRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:267
	 * @test_Strategy: In the first request the portlet creates a
	 *                 render URL with parameters using createRenderURL(). 
	 *                 In the second reques the portlet uses a 
	 *                 PortletRequestDispatcher to forward to the servlet. 
	 *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.  
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscRenderForwardTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscRenderForwardTestPortlet");

		runStdTestForRenderWithParameters(portletInfo);
	}


	/*
	 * @testName: RequestMethodsParameterMiscServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:283
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL with parameters using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.  
	 * @assertion: The following methods of the HttpServletRequest must 
	 *             be equivalent to the methods of the PortletRequest 
	 *             of similar name with the provision defined in PLT.18.1.1 
	 *             Query Strings in Request Dispatcher Paths Section: 
	 *             getParameter, getParameterNames, getParameterValues 
	 *             and getParameterMap
	 */
	public void RequestMethodsParameterMiscServeResourceForwardTest() throws Fault {

		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsParameterMiscServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo); 
	}
	
    /*
	 * @testName: RequestMethodsReturn0ActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:244
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). Checks that 
	 *                 the specified  methods return 0 in the servlet.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must return 0: getRemotePort and getLocalPort.          
	 */
	public void RequestMethodsReturn0ActionForwardTest() throws Fault {
		/*
		 * Sets the GET request to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"RequestMethodsReturn0ActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo);    	       
	}
    
    
    /*
     * @testName: RequestMethodsReturn0EventingForwardTest
     * @assertion_ids: PORTLET:SPEC:244
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 Checks that the specified  methods return 0 in the servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return 0: getRemotePort and getLocalPort.        
     */
    public void RequestMethodsReturn0EventingForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsReturn0EventingForwardTestPortlet");

        runStdTestForProcessEvent(portletInfo);	
    }
    
    
    /*
     * @testName: RequestMethodsReturn0RenderForwardTest
     * @assertion_ids: PORTLET:SPEC:263
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. Checks that the specified 
	 *                 methods return 0 in the servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return 0: getRemotePort and getLocalPort.       
     */
    public void RequestMethodsReturn0RenderForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsReturn0RenderForwardTestPortlet");

        runStdTestForRender(portletInfo);
    }

    
    /*
	 * @testName: RequestMethodsReturn0ServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:279
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). Checks that 
	 *                 the specified methods return 0 in the servlet.
	 * @assertion: The following methods of the HttpServletRequest
	 *             must return 0: getRemotePort and getLocalPort.    
	 */
	public void RequestMethodsReturn0ServeResourceForwardTest() throws Fault {
	    /*
	     * Sets the GET request to be sent out to the server.
	     */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(), 
				"RequestMethodsReturn0ServeResourceForwardTestPortlet");
	
	    runStdTestForServeResource(portletInfo); 
	}
    
    /*
     * @testName: RequestMethodsReturnNullActionForwardTest
     * @assertion_ids: PORTLET:SPEC:243
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). Checks that 
	 *                 the specified  methods return null in the servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return null: getRemoteAddr, getRemoteHost, 
     *             getLocalAddr, getLocalName, getRealPath and getRequestURL.         
     */
    public void RequestMethodsReturnNullActionForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsReturnNullActionForwardTestPortlet");

    	runStdTestForProcessAction(portletInfo); 
    }


    /*
     * @testName: RequestMethodsReturnNullEventingForwardTest
     * @assertion_ids: PORTLET:SPEC:243
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 Checks that the specified  methods return null in the servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return null: getRemoteAddr, getRemoteHost, 
     *             getLocalAddr, getLocalName, getRealPath and getRequestURL.        
     */
    public void RequestMethodsReturnNullEventingForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsReturnNullEventingForwardTestPortlet");

    	runStdTestForProcessEvent(portletInfo);
    }


    /*
     * @testName: RequestMethodsReturnNullRenderForwardTest
     * @assertion_ids: PORTLET:SPEC:262
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. Checks that the specified 
	 *                 methods return null in the servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return null: getRemoteAddr, getRemoteHost, 
     *             getLocalAddr, getLocalName, getRealPath and getRequestURL.        
     */
    public void RequestMethodsReturnNullRenderForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsReturnNullRenderForwardTestPortlet");

    	runStdTestForRender(portletInfo);
    }


    /*
     * @testName: RequestMethodsReturnNullServeResourceForwardTest
     * @assertion_ids: PORTLET:SPEC:278
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). Checks that 
	 *                 the specified methods return null in the servlet.
     * @assertion: The following methods of the HttpServletRequest
     *             must return null: getRemoteAddr, getRemoteHost, 
     *             getLocalAddr, getLocalName, getRealPath and getRequestURL.        
     */
    public void RequestMethodsReturnNullServeResourceForwardTest() throws Fault {
    	/*
    	 * Sets the GET request to be sent out to the server.
    	 */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsReturnNullServeResourceForwardTestPortlet");

    	runStdTestForServeResource(portletInfo); 
    }
    
    /*
     * @testName: RequestMethodsReturnPathInfoActionForwardTest
     * @assertion_ids: PORTLET:SPEC:240;PORTLET:SPEC:245
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with a 
     *                 query string to forward to the servlet in processAction(). 
     *                 Checks that the specified methods return correct values 
     *                 in the servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
    public void RequestMethodsReturnPathInfoActionForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnPathInfoActionForwardTestPortlet");

        runStdTestForProcessAction(portletInfo);        
    }
	
    
	/*
     * @testName: RequestMethodsReturnPathInfoEventingForwardTest
     * @assertion_ids: PORTLET:SPEC:240;PORTLET:SPEC:245
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher created with 
	 *                 a query string to forward to the servlet. 
     *                 Checks that the specified methods return correct values 
     *                 in the servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
    public void RequestMethodsReturnPathInfoEventingForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnPathInfoEventingForwardTestPortlet");

        runStdTestForProcessEvent(portletInfo);
    }
    
    
	/*
     * @testName: RequestMethodsReturnPathInfoRenderForwardTest
     * @assertion_ids: PORTLET:SPEC:240;PORTLET:SPEC:264
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher created with 
	 *                 a query string to forward to the servlet. 
	 *                 Checks that the specified methods return 
	 *                 correct values in the servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
    public void RequestMethodsReturnPathInfoRenderForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsReturnPathInfoRenderForwardTestPortlet");

        runStdTestForRender(portletInfo);
    }
    
	/*
     * @testName: RequestMethodsReturnPathInfoServeResourceForwardTest
     * @assertion_ids: PORTLET:SPEC:280
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher created with 
	 *                 a query string to forward to
	 *                 the servlet in serveResource(). 
	 *                 Checks that the specified methods return 
	 *                 correct values in the servlet.  
     *                 The getPathTranslated method is untestable because of 
     *                 its ambiguous behavior as stated in the servlet 
     *                 specification.
     * @assertion: The following methods of the HttpServletRequest
     *             must return the path and query string information
     *             used to obtain the PortletRequestDispatcher object:
     *             getPathInfo, getPathTranslated, getQueryString,
     *             getRequestURI and getServletPath.       
     */
	public void RequestMethodsReturnPathInfoServeResourceForwardTest() throws Fault {
	    /*
	     * Sets the GET request to be sent out to the server.
	     */
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                                    "RequestMethodsReturnPathInfoServeResourceForwardTestPortlet");
	
	    runStdTestForServeResource(portletInfo); 
	}
	
	
	/*
     * @testName: RequestMethodsSecondMiscMiscActionForwardTest
     * @assertion_ids: PORTLET:SPEC:248;PORTLET:SPEC:254
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.              
     * @assertion: In case of an include from processAction, the following 
     *             methods of the HttpServletRequest must be based on the 
     *             corresponding methods of the ActionRequest: getCharacterEncoding, 
     *             getContentType, getContentLength and getMethod.
     *             The getProtocol method of the HttpServletRequest must 
     *             always return HTTP/1.1.
     */
    public void RequestMethodsSecondMiscMiscActionForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsSecondMiscMiscActionForwardTestPortlet");
        
        runStdTestForProcessAction(portletInfo);  	
    }
    
    
    /*
     * @testName: RequestMethodsSecondMiscMiscEventingForwardTest
     * @assertion_ids: PORTLET:SPEC:249;PORTLET:SPEC:250;PORTLET:SPEC:251;PORTLET:SPEC:254
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.                
     * @assertion: In case of an include from processEvent, the following methods
     *             of the HttpServletRequest must return null:
     *             getCharacterEncoding, getContentType. The getContentLength 
     *             method of the HttpServletRequest must return 0.
     *             The getMethod method of the HttpServletRequest must be based 
     *             on the corresponding method of the ActionRequest triggering this event.
     *             The getProtocol method of the HttpServletRequest must always 
     *             return HTTP/1.1.
     */
    public void RequestMethodsSecondMiscMiscEventingForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsSecondMiscMiscEventingForwardTestPortlet");
        
        runStdTestForProcessEvent(portletInfo); 
    }
	
    
    /*
     * @testName: RequestMethodsSecondMiscMiscRenderForwardTest
     * @assertion_ids: PORTLET:SPEC:267;PORTLET:SPEC:268;PORTLET:SPEC:271;PORTLET:SPEC:272
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the 
	 *                 expected values saved in the session. 
     * @assertion: The following methods of the HttpServletRequest
     *             return null: getCharacterEncoding and getContentType.
     *             The getContentLength method of the HttpServletRequest 
     *             must return 0.
     *             The getMethod method of the HttpServletRequest must 
     *             always return GET. The getProtocol method of the 
     *             HttpServletRequest must always return HTTP/1.1.             
     */
    public void RequestMethodsSecondMiscMiscRenderForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "RequestMethodsSecondMiscMiscRenderForwardTestPortlet");

        runStdTestForRender(portletInfo);
    }
    
    
    /*
     * @testName: RequestMethodsSecondMiscMiscServeResourceForwardTest
     * @assertion_ids: #rev31#kap19#282;#rev31#kap19#286
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session. 
     * @assertion: The following methods of the HttpServletRequest must be 
     *             equivalent to the methods of the ResourceRequest of 
     *             similar name: 
     *             getCharacterEncoding, getContentLength, getContentType 
     *             and getMethod.
     *             The getProtocol method of the HttpServletRequest must 
     *             always return HTTP/1.1.
     */
    public void RequestMethodsSecondMiscMiscServeResourceForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"RequestMethodsSecondMiscMiscServeResourceForwardTestPortlet");
     
        runStdTestForServeResource(portletInfo); 
    }
    
    
    /*
     * @testName: RequestMethodsSessionMiscActionForwardTest
     * @assertion_ids: PORTLET:SPEC:253
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets a session 
     *                 attribute in thePortletSession with APPLICATION_SCOPE 
     *                 and uses a PortletRequestDispatcher to forward to
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when forward returns.               
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscActionForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscActionForwardTestPortlet");
        
        runStdTestForProcessAction(portletInfo);  
    }
    
    
    /*
     * @testName: RequestMethodsSessionMiscEventingForwardTest
     * @assertion_ids: PORTLET:SPEC:253
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 sets a session attribute in the
     *                 PortletSession with APPLICATION_SCOPE and uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when forward returns.               
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscEventingForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscEventingForwardTestPortlet");

        runStdTestForProcessEvent(portletInfo);           
    }

    
    /*
     * @testName: RequestMethodsSessionMiscRenderForwardTest
     * @assertion_ids: PORTLET:SPEC:270
     * @test_Strategy: Makes a request to the portlet that sets a session 
     *                 attribute in the PortletSession with APPLICATION_SCOPE 
     *                 and uses a PortletRequestDispatcher to forward to
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when forward returns.                    
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscRenderForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscRenderForwardTestPortlet");

		/*****************************************************************
         * FIRST TRIP: To to send the first request to the render() method
         *             that forwards to the servlet.
         *****************************************************************/
        
        String request = getPortalURL(portletInfo);
        setRequestProperty(REQUEST, request);

        /*
         * Sets the test criteria.
         */
        setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
            ResultWriter.getFailedString(getTestName()));

        /*
         * Invokes the test.
         */
        HttpResponse firstResponse = invoke();
                
        
        /*****************************************************************
         * SECOND TRIP: To send the second request to the render() method
         *              to print the result. 
         *****************************************************************/
                  
         /*
          * Sets the second request to be sent out to the server.
          */
        setRequestProperty(REQUEST, request);

        /*
         * Sets the test criteria.
         */
        setCriteriaProperty(SEARCH_STRING,
    	        ResultWriter.getPassedString(getTestName()));

        /*
         * Invokes the test.
         */
        invoke(firstResponse); 	
    }
    
    
    /* 
     * @testName: RequestMethodsSessionMiscServeResourceForwardTest
     * @assertion_ids: #rev31#kap19#285
     * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet sets a session attribute 
     *                 in the PortletSession with APPLICATION_SCOPE 
     *                 and uses a PortletRequestDispatcher to forward to
	 *                 the servlet. Checks that the getSession() method 
	 *                 returns a non-null value and checks for the session attribute 
	 *                 using session.getAttribute() and session.getAttributeNames().
	 *                 Removes the attribute using session.removeAttribute() and
	 *                 sets a new one using session.setAttribute()
	 *                 Checks that the session attribute is removed
	 *                 and the new one is set in the portlet when forward returns.              
     * @assertion: The following method of the HttpServletRequest must provide
     *             the functionality defined by the Servlet Specification:
     *             getSession()
     */
    public void RequestMethodsSessionMiscServeResourceForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = 
        	new TSPortletInfo(getDefaultPortletApp(),
        			"RequestMethodsSessionMiscServeResourceForwardTestPortlet");
        
		 /*****************************************************************
	     * FIRST TRIP: To get the ResourceURL string.
	     *****************************************************************/
	    
	    String request = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, request);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
	        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    HttpResponse firstResponse = invoke();
	            
	    /*
	     * Extracts the ResourceURL for the serveResource() method from the
	     * content of the HttpResponse of the first pass.
	     */
	    String resourceUrl = PortletURLClientTag.extractContent(firstResponse);
	    
	    /*****************************************************************
	     * SECOND TRIP: To send the second request to the 
	     *              serveResource() method.
	     *****************************************************************/
	              
	     /*
	      * Sets the second request to be sent out to the server.
	      */
	    String secondRequest = getPortalReturnURL(resourceUrl);
	    setRequestProperty(REQUEST, secondRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
		        ResultWriter.getPassedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    HttpResponse secondResponse = invoke(firstResponse);
	    
	    /*****************************************************************
	     * THIRD TRIP: To send the third request to the 
	     *              render() method that prints the result.
	     *****************************************************************/
	              
	     /*
	      * Sets the second request to be sent out to the server.
	      */
	    String thirdRequest = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, thirdRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(SEARCH_STRING,
		        ResultWriter.getPassedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    invoke(secondResponse);
    }

	
	/* 
	 * @testName: ResponseBufferClearedRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:236
	 * @test_Strategy: Makes a request to the portlet that writes out 
	 *                 some content and uses a PortletRequestDispatcher 
	 *                 to forward to the servlet, when a response buffer is available.
	 *                 The test passes if the content written by the portlet has been cleared.
	 * @assertion: If output data exists in the response buffer that has
	 * 			   not been committed, the content must be cleared before
	 * 			   the target servlets service method is called.
	 */
	public void ResponseBufferClearedRenderForwardTest() throws Fault {
	
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                      "ResponseBufferClearedRenderForwardTestPortlet");
	    
	    /*******************************************************************
	     * FIRST TRIP:: To send a request for the dispatcher.
	     ******************************************************************/
	     
	     /*
	      * Sets the GET request to be sent out to the server.
	      */
	
	    String firstRequest = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, firstRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
	        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    invoke();  
	}

	/*
	 * @testName: ResponseBufferClearedServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:236
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet writes out 
	 *                 some content and uses a PortletRequestDispatcher 
	 *                 to forward to the servlet, when a response buffer is available.
	 *                 The test passes if the content written by the portlet has been cleared.
	 * @assertion: If output data exists in the response buffer that has
	 * 			   not been committed, the content must be cleared before
	 * 			   the target servlets service method is called.
	 */
	public void ResponseBufferClearedServeResourceForwardTest() throws Fault {
	
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                      "ResponseBufferClearedServeResourceForwardTestPortlet");
	
	    /*****************************************************************
	     * FIRST TRIP: To get the ResourceURL string.
	     *****************************************************************/
	    
	    String request = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, request);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
	        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    HttpResponse firstResponse = invoke();
	            
	    /*
	     * Extracts the ResourceURL for the serveResource() method from the
	     * content of the HttpResponse of the first pass.
	     */
	    String resourceUrl = PortletURLClientTag.extractContent(firstResponse);
	    
	    /*****************************************************************
	     * SECOND TRIP: To send the second request to the 
	     *              serveResource() method.
	     *****************************************************************/
	              
	     /*
	      * Sets the second request to be sent out to the server.
	      */
	    String secondRequest = getPortalReturnURL(resourceUrl);
	    setRequestProperty(REQUEST, secondRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
		        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    invoke(firstResponse);  
	}
	
	/*
	 * @testName: ResponseBufferPortletCommitForwardTest
	 * @assertion_ids: PORTLET:SPEC:187 
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL() and flushes 
     *                 the reponse buffer. Uses a PortletRequestDispatcher 
     *                 to forward to the servlet and catches the 
     *                 IllegalStateException.  
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource()and catches the 
     *                 IllegalStateException.
     *                 The test passes, when both IllegalStateException 
     *                 were thrown. 
	 * @assertion: If the response has been committed, an
	 * 			   IllegalStateException must be thrown.
	 */
	public void ResponseBufferPortletCommitForwardTest() throws Fault{
		
		TSPortletInfo portletInfo = new TSPortletInfo(
		                getDefaultPortletApp(),
		  "ResponseBufferPortletCommitForwardTestPortlet");
		
		/*******************************************************************
		* FIRST TRIP:
		******************************************************************/
		
		/*
		* Sets the GET request to be sent out to the server.
		*/
		
		String firstRequest = getPortalURL(portletInfo);
		setRequestProperty(REQUEST, firstRequest);
		
		setCriteriaProperty(SEARCH_STRING,
		ResultWriter.getPassedString(getTestName()));
		
		/*
		* Invokes the test.
		*/
		HttpResponse firstResponse = invoke();  
		/*******************************************************************
		* SECOND TRIP: 
		******************************************************************/
		String resourceURL = 
			PortletURLClientTag.extractContent(firstResponse);
				
		String secondRequest = getPortalReturnURL(resourceURL);
		setRequestProperty(REQUEST, secondRequest);
		
		setCriteriaProperty(SEARCH_STRING,
				ResultWriter.getPassedString(getTestName()));
		
		/*
		* Invokes the test.
		*/
		invoke(firstResponse);
	}

	/* 
	 * @testName: ResponseBufferCommittedRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:238
	 * @test_Strategy: Makes a request to the portlet that writes out 
	 *                 some content and uses a PortletRequestDispatcher 
	 *                 to forward to the servlet.
	 *                 Writes out some content, after forward returned.
	 *                 The test passes if nothing is written out after 
	 *                 forward returned.
	 * @assertion: Before the forward method of the RequestDispatcher interface 
	 *             returns, the response content must be sent, committed and 
	 *             closed by the portlet container.
	 */
	public void ResponseBufferCommittedRenderForwardTest() throws Fault {
	
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                      "ResponseBufferCommittedRenderForwardTestPortlet");
	
	    /*******************************************************************
	     * FIRST TRIP:: To send a request for the dispatcher.
	     ******************************************************************/
	     
	     /*
	      * Sets the GET request to be sent out to the server.
	      */
	
	    String firstRequest = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, firstRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
	        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    invoke();  
	}

	/* 
	 * @testName: ResponseBufferCommittedServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:238
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource().
	 *                 Writes out some content, after forward returned.
	 *                 The test passes if nothing is written out after 
	 *                 forward returned.
	 * @assertion: Before the forward method of the RequestDispatcher interface 
	 *             returns, the response content must be sent, committed and 
	 *             closed by the portlet container.
	 */
	public void ResponseBufferCommittedServeResourceForwardTest() throws Fault {
	
	    TSPortletInfo portletInfo = new TSPortletInfo(
	                                    getDefaultPortletApp(),
	                      "ResponseBufferCommittedServeResourceForwardTestPortlet");
	
	    /*****************************************************************
	     * FIRST TRIP: To get the ResourceURL string.
	     *****************************************************************/
	    
	    String request = getPortalURL(portletInfo);
	    setRequestProperty(REQUEST, request);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
	        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    HttpResponse firstResponse = invoke();
	            
	    /*
	     * Extracts the ResourceURL for the serveResource() method from the
	     * content of the HttpResponse of the first pass.
	     */
	    String resourceUrl = PortletURLClientTag.extractContent(firstResponse);
	    
	    /*****************************************************************
	     * SECOND TRIP: To send the second request to the 
	     *              serveResource() method.
	     *****************************************************************/
	              
	     /*
	      * Sets the second request to be sent out to the server.
	      */
	    String secondRequest = getPortalReturnURL(resourceUrl);
	    setRequestProperty(REQUEST, secondRequest);
	
	    /*
	     * Sets the test criteria.
	     */
	    setCriteriaProperty(UNEXPECTED_RESPONSE_MATCH,
		        ResultWriter.getFailedString(getTestName()));
	
	    /*
	     * Invokes the test.
	     */
	    invoke(firstResponse);  
	}

	
	/*
	 * @testName: ResponseMethodsGetOutputStreamActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:256
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). 
	 *                 In the servlet the getOutputStream method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             an that ignores any output written to it: getOutputStream.
	 */
	public void ResponseMethodsGetOutputStreamActionForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetOutputStreamEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:256
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.
	 *                 In the servlet the getOutputStream method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             an that ignores any output written to it: getOutputStream.
	 */
	public void ResponseMethodsGetOutputStreamEventingForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetOutputStreamRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:274
	 * @test_Strategy: Makes a Response to the portlet that uses
	 *                 a PortletResponseDispatcher to forward to
	 *                 the servlet. In the servlet the getOutputStream 
	 *                 method is invoked. Test passes if this 
	 *                 method returns a non-null value for the 
	 *                 PrintOutputStream object.
	 * @assertion: The following methods of the HttpServletResponse 
	 *             must be equivalent to the methods of the RenderResponse 
	 *             of similar name: getOutputStream().
	 */
	public void ResponseMethodsGetOutputStreamRenderForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: ResponseMethodsGetOutputStreamServeResourceForwardTest
	 * @assertion_ids: #rev31#kap19#283
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource().
	 *                 In the servlet the getOutputStream method is invoked. 
	 *                 Test passes if this method returns
	 *                 a non-null value for the PrintOutputStream object.
	 * @assertion: The following method of the HttpServletResponse must be  
	 *             equivalent to the method of the ResourceResponse of 
	 *             similar name: getOutputStream().
	 */
	public void ResponseMethodsGetOutputStreamServeResourceForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetOutputStreamServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
    
    
    /*
	 * @testName: ResponseMethodsGetWriterActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:256
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in processAction(). 
	 *                 In the servlet the getWriter method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             a writer that ignores any output written to it: getWriter.
	 */
	public void ResponseMethodsGetWriterActionForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetWriterEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:256
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to include the servlet.
	 *                 In the servlet the getWriter method is invoked. 
	 *                 Test passes if this method returns a non-null value.
	 * @assertion: The following methods of the HttpServletResponse must return 
	 *             a writer that ignores any output written to it: getWriter.
	 */
	public void ResponseMethodsGetWriterEventingForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsGetWriterRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:274
	 * @test_Strategy: Makes a Response to the portlet that uses
	 *                 a PortletResponseDispatcher to forward to
	 *                 the servlet. In the servlet the getWriter 
	 *                 method is invoked. Test passes if this 
	 *                 method returns a non-null value for the 
	 *                 PrintWriter object.
	 * @assertion: The following methods of the HttpServletResponse 
	 *             must be equivalent to the methods of the RenderResponse 
	 *             of similar name: getWriter().
	 */
	public void ResponseMethodsGetWriterRenderForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: ResponseMethodsGetWriterServeResourceForwardTest
	 * @assertion_ids: #rev31#kap19#283
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to include
	 *                 the servlet in serveResource().
	 *                 In the servlet the getWriter method is invoked. 
	 *                 Test passes if this method returns
	 *                 a non-null value for the PrintWriter object.
	 * @assertion: The following method of the HttpServletResponse must be  
	 *             equivalent to the method of the ResourceResponse of 
	 *             similar name: getWriter().
	 */
	public void ResponseMethodsGetWriterServeResourceForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsGetWriterServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo);
	}

    
	/*
	 * @testName: ResponseMethodsMiscMiscActionForwardTest
	 * @assertion_ids: PORTLET:SPEC:255;PORTLET:SPEC:257
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.  
	 * @assertion: The following methods of the HttpServletResponse must 
	 *             return null: getCharacterEncoding, getContentType, 
	 *             getLocale and getBufferSize.
	 *             The following methods of the HttpServletResponse must 
	 *             be equivalent to the methods of the ActionResponse
	 *             of similar name: encodeURL and encodeUrl.
	 */
	public void ResponseMethodsMiscMiscActionForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscActionForwardTestPortlet");

		runStdTestForProcessAction(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsMiscMiscEventingForwardTest
	 * @assertion_ids: PORTLET:SPEC:255;PORTLET:SPEC:257
	 * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 The servlet compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session.     
	 * @assertion: The following methods of the HttpServletResponse must 
	 *             return null: getCharacterEncoding, getContentType, 
	 *             getLocale and getBufferSize.
	 *             The following methods of the HttpServletResponse must 
	 *             be equivalent to the methods of the EventResponse 
	 *             of similar name: encodeURL and encodeUrl.
	 */
	public void ResponseMethodsMiscMiscEventingForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscEventingForwardTestPortlet");

		runStdTestForProcessEvent(portletInfo);
	}
	
	/*
	 * @testName: ResponseMethodsMiscMiscRenderForwardTest
	 * @assertion_ids: PORTLET:SPEC:274
	 * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. The servlet compares the return 
	 *                 values of the specified methods with the 
	 *                 expected values saved in the session. 
	 * @assertion: The following methods of the HttpServletResponse must be 
	 *             equivalent to the methods of the RenderResponse of
	 *             similar name: getCharacterEncoding, getBufferSize, 
	 *             isCommitted, encodeURL and encodeUrl.
	 *             The getLocale method of the HttpServletResponse must be 
	 *             based on the getLocale method of the RenderResponse.
	 */
	public void ResponseMethodsMiscMiscRenderForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscRenderForwardTestPortlet");

		runStdTestForRender(portletInfo);
	}
	
	
	/*
	 * @testName: ResponseMethodsMiscMiscServeResourceForwardTest
	 * @assertion_ids: #rev31#kap19#288
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). The servlet 
	 *                 compares the return values of the specified 
	 *                 methods with the expected values saved in 
	 *                 the session. 
	 * @assertion: The following methods of the HttpServletResponse must be 
	 *             equivalent to the methods of the ResourceResponse of
	 *             similar name: getCharacterEncoding, getContentType, getBufferSize, 
	 *             isCommitted, getLocale, encodeURL and encodeUrl.
	 */
	public void ResponseMethodsMiscMiscServeResourceForwardTest() 
		throws Fault {
		/*
		 * Sets the GET Response to be sent out to the server.
		 */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsMiscMiscServeResourceForwardTestPortlet");

		runStdTestForServeResource(portletInfo);
	}
	

	/*
     * @testName: ResponseMethodsReturnNullActionForwardTest
     * @assertion_ids: PORTLET:SPEC:255
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in processAction(). Checks that 
	 *                 the specified  methods return null in the servlet.
     * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl         
     */
    public void ResponseMethodsReturnNullActionForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
        TSPortletInfo portletInfo = new TSPortletInfo(
                                        getDefaultPortletApp(),
                                        "ResponseMethodsReturnNullActionForwardTestPortlet");

        runStdTestForProcessAction(portletInfo); 
    }
    
    
    /*
     * @testName: ResponseMethodsReturnNullEventingForwardTest
     * @assertion_ids: PORTLET:SPEC:255
     * @test_Strategy: In the first request the portlet creates an 
     *                 actionURL using createActionURL(). 
     *                 In the second request the portlet sets an event 
     *                 in processAction() and when processEvent() is invoked it 
     *                 uses a PortletRequestDispatcher to forward to the servlet. 
     *                 Checks that the specified  methods return null in the servlet.
     * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl       
     */
    public void ResponseMethodsReturnNullEventingForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"ResponseMethodsReturnNullEventingForwardTestPortlet");

        runStdTestForProcessEvent(portletInfo);
    }
    
    
    /*
     * @testName: ResponseMethodsReturnNullRenderForwardTest
     * @assertion_ids: rev31#kap19#273
     * @test_Strategy: Makes a request to the portlet that uses
	 *                 a PortletRequestDispatcher to forward to
	 *                 the servlet. Checks that the specified 
	 *                 methods return null in the servlet.
     * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl.       
     */
    public void ResponseMethodsReturnNullRenderForwardTest() throws Fault {
        /*
         * Sets the GET request to be sent out to the server.
         */
    	TSPortletInfo portletInfo = new TSPortletInfo(
    			getDefaultPortletApp(),
    			"ResponseMethodsReturnNullRenderForwardTestPortlet");

        runStdTestForRender(portletInfo);
    }

    
    /*
	 * @testName: ResponseMethodsReturnNullServeResourceForwardTest
	 * @assertion_ids: PORTLET:SPEC:287
	 * @test_Strategy: In the first request the portlet creates a
     *                 resourceURL using createResourceURL(). 
     *                 In the second request the portlet uses a 
     *                 PortletRequestDispatcher to forward to
	 *                 the servlet in serveResource(). Checks that 
	 *                 the specified methods return null in the servlet.
	 * @assertion: The following methods of the HttpServletResponse must 
     *             return null: encodeRedirectURL, encodeRedirectUrl.       
	 */
	public void ResponseMethodsReturnNullServeResourceForwardTest() throws Fault {
	    /*
	     * Sets the GET request to be sent out to the server.
	     */
		TSPortletInfo portletInfo = new TSPortletInfo(
				getDefaultPortletApp(),
				"ResponseMethodsReturnNullServeResourceForwardTestPortlet");
	
	    runStdTestForServeResource(portletInfo); 
	}

    
    
}
